% Auto-generated chapter 10 for ibnmajah
% Hadiths in this chapter: 78

\hadithdefcmd{ibnmajah}{2016}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، وَعَبْدُ اللَّهِ بْنُ عَامِرِ بْنِ زُرَارَةَ، وَمَسْرُوقُ بْنُ الْمَرْزُبَانِ، قَالُوا حَدَّثَنَا يَحْيَى بْنُ زَكَرِيَّا بْنِ أَبِي زَائِدَةَ، عَنْ صَالِحِ بْنِ صَالِحِ بْنِ حَىٍّ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، ‏.‏ أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ طَلَّقَ حَفْصَةَ ثُمَّ رَاجَعَهَا ‏.‏\hadithno{2016}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Umar bin Khattab that:the Messenger of Allah divorced Hafsah then took her back}}
\hadithdefcmd{ibnmajah}{2017}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُؤَمَّلٌ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَا بَالُ أَقْوَامٍ يَلْعَبُونَ بِحُدُودِ اللَّهِ يَقُولُ أَحَدُهُمْ قَدْ طَلَّقْتُكِ قَدْ رَاجَعْتُكِ ‏.‏ قَدْ طَلَّقْتُكِ ‏"‏ ‏.‏\hadithno{2017}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Musa that:the Messenger of Allah said: What is wrong with people who play with the limits imposed by Allah, and one of them says: "I divorce you, I take you back, I divorce you?}}
\hadithdefcmd{ibnmajah}{2018}{حَدَّثَنَا كَثِيرُ بْنُ عُبَيْدٍ الْحِمْصِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ خَالِدٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ الْوَلِيدِ الْوَصَّافِيِّ، عَنْ مُحَارِبِ بْنِ دِثَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أَبْغَضُ الْحَلاَلِ إِلَى اللَّهِ الطَّلاَقُ ‏"‏ ‏.‏\hadithno{2018}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Abdullah bin 'Umar that:the Messenger of Allah said: "The most hated of permissible things to Allah is divorce}}
\hadithdefcmd{ibnmajah}{2019}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ طَلَّقْتُ امْرَأَتِي وَهِيَ حَائِضٌ فَذَكَرَ ذَلِكَ عُمَرُ لِرَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَ ‏ "‏ مُرْهُ فَلْيُرَاجِعْهَا حَتَّى تَطْهُرَ ثُمَّ تَحِيضَ ثُمَّ تَطْهُرَ ثُمَّ إِنْ شَاءَ طَلَّقَهَا قَبْلَ أَنْ يُجَامِعَهَا وَإِنْ شَاءَ أَمْسَكَهَا فَإِنَّهَا الْعِدَّةُ الَّتِي أَمَرَ اللَّهُ ‏"‏ ‏.‏\hadithno{2019}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ibn 'Umar said:"I divorced my wife when she was menstruating. 'Umar mentioned that to the Messenger of Allah and he said: 'Tell him to take her back until she becomes pure (i.e., her period ends), then she has her period (again), then she becomes pure (again), then if he wishes he may divorce her before having sexual relations with her, and if he wishes he may keep her. This is the waiting period that Allah has enjoined}}
\hadithdefcmd{ibnmajah}{2020}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ سُفْيَانَ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي الأَحْوَصِ، عَنْ عَبْدِ اللَّهِ، قَالَ طَلاَقُ السُّنَّةِ أَنْ يُطَلِّقَهَا طَاهِرًا مِنْ غَيْرِ جِمَاعٍ ‏.‏\hadithno{2020}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abdullah said:"Divorce according to the Sunnah means divorcing her when she is pure, ( i.e., not menstruating) and without having had intercourse with her (during that cycle)}}
\hadithdefcmd{ibnmajah}{2021}{حَدَّثَنَا عَلِيُّ بْنُ مَيْمُونٍ الرَّقِّيُّ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، عَنِ الأَعْمَشِ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي الأَحْوَصِ، عَنْ عَبْدِ اللَّهِ، قَالَ طَلاَقُ السُّنَّةِ يُطَلِّقُهَا عِنْدَ كُلِّ طُهْرٍ تَطْلِيقَةً فَإِذَا طَهُرَتِ الثَّالِثَةَ طَلَّقَهَا وَعَلَيْهَا بَعْدَ ذَلِكَ حَيْضَةٌ ‏.‏\hadithno{2021}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Abdullah said:"Divorce according to the Sunnah means divorcing her with one divorce in each cycle when she is pure, then when she becomes pure the third time, then he pronounces divorce again, and after that she must wait one more menstrual cycle}}
\hadithdefcmd{ibnmajah}{2022}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا هِشَامٌ، عَنْ مُحَمَّدٍ، عَنْ يُونُسَ بْنِ جُبَيْرٍ أَبِي غَلاَّبٍ، قَالَ سَأَلْتُ ابْنَ عُمَرَ عَنْ رَجُلٍ، طَلَّقَ امْرَأَتَهُ وَهِيَ حَائِضٌ فَقَالَ تَعْرِفُ عَبْدَ اللَّهِ بْنَ عُمَرَ طَلَّقَ امْرَأَتَهُ وَهِيَ حَائِضٌ فَأَتَى عُمَرُ النَّبِيَّ ـ صلى الله عليه وسلم ـ فَأَمَرَهُ أَنْ يُرَاجِعَهَا ‏.‏ قُلْتُ أَيُعْتَدُّ بِتِلْكَ قَالَ أَرَأَيْتَ إِنْ عَجَزَ وَاسْتَحْمَقَ\hadithno{2022}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Yunus bin Jubair, Abu Ghallab, said:"I asked Ibn 'Umar about a man who divorced his wife when she was menstruating. He said: 'Do you know 'Abdullah bin 'Umar? He divorced his wife when she was menstruating then 'Umar came to the Prophet (ﷺ) (and told him what had happened). He ordered him to take her back.' I said: 'Will that be counted (as a divorce)?' He said: 'Do You think he was helpless and behaving foolishly? [i.e., Yes, it counts (as a divorce]}}
\hadithdefcmd{ibnmajah}{2023}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، مَوْلَى آلِ طَلْحَةَ عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، أَنَّهُ طَلَّقَ امْرَأَتَهُ وَهِيَ حَائِضٌ فَذَكَرَ ذَلِكَ عُمَرُ لِلنَّبِيِّ ـ صلى الله عليه وسلم ـ فَقَالَ ‏ "‏ مُرْهُ فَلْيُرَاجِعْهَا ثُمَّ لِيُطَلِّقْهَا وَهِيَ طَاهِرٌ أَوْ حَامِلٌ ‏"‏ ‏.‏\hadithno{2023}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Umar that:he divorced his wife when she was menstruating, and 'Umar mentioned that to the Prophet (ﷺ). He said: "Tell him to take her back then divorce her when she is pure (not menstruating) or pregnant}}
\hadithdefcmd{ibnmajah}{2024}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ إِسْحَاقَ بْنِ أَبِي فَرْوَةَ، عَنْ أَبِي الزِّنَادِ، عَنْ عَامِرٍ الشَّعْبِيِّ، قَالَ قُلْتُ لِفَاطِمَةَ بِنْتِ قَيْسٍ حَدِّثِينِي عَنْ طَلاَقِكِ، ‏.‏ قَالَتْ طَلَّقَنِي زَوْجِي ثَلاَثًا وَهُوَ خَارِجٌ إِلَى الْيَمَنِ فَأَجَازَ ذَلِكَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏\hadithno{2024}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Amir Sha'bi said:"I said to Fatimah bint Qais: 'Tell me about your divorce.' She said: 'My husband divorced me three times when he was leaving for Yemen, and the Messenger of Allah (ﷺ) allowed that}}
\hadithdefcmd{ibnmajah}{2025}{حَدَّثَنَا بِشْرُ بْنُ هِلاَلٍ الصَّوَّافُ، حَدَّثَنَا جَعْفَرُ بْنُ سُلَيْمَانَ الضُّبَعِيُّ، عَنْ يَزِيدَ الرِّشْكِ، عَنْ مُطَرِّفِ بْنِ عَبْدِ اللَّهِ بْنِ الشِّخِّيرِ، أَنَّ عِمْرَانَ بْنَ الْحُصَيْنِ، سُئِلَ عَنْ رَجُلٍ، يُطَلِّقُ امْرَأَتَهُ ثُمَّ يَقَعُ بِهَا وَلَمْ يُشْهِدْ عَلَى طَلاَقِهَا وَلاَ عَلَى رَجْعَتِهَا ‏.‏ فَقَالَ عِمْرَانُ طَلَّقْتَ بِغَيْرِ سُنَّةٍ وَرَاجَعْتَ بِغَيْرِ سُنَّةٍ أَشْهِدْ عَلَى طَلاَقِهَا وَعَلَى رَجْعَتِهَا ‏.‏\hadithno{2025}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Imran bin Husain:was asked about a man who divorced his wife then had intercourse with her, and there were no witnesses to his divorcing her or his taking her back. 'Imran said: "You have divorced (her) in a manner that is not according to the Sunnah, and you have taken her back in a manner that is not according to the Sunnah. Bring people to witness your divorcing her and taking her back}}
\hadithdefcmd{ibnmajah}{2026}{حَدَّثَنَا مُحَمَّدُ بْنُ عُمَرَ بْنِ هَيَّاجٍ، حَدَّثَنَا قَبِيصَةُ بْنُ عُقْبَةَ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرِو بْنِ مَيْمُونٍ، عَنْ أَبِيهِ، عَنِ الزُّبَيْرِ بْنِ الْعَوَّامِ، أَنَّهُ كَانَتْ عِنْدَهُ أُمُّ كُلْثُومٍ بِنْتُ عُقْبَةَ فَقَالَتْ لَهُ وَهِيَ حَامِلٌ طَيِّبْ نَفْسِي بِتَطْلِيقَةٍ ‏.‏ فَطَلَّقَهَا تَطْلِيقَةً ثُمَّ خَرَجَ إِلَى الصَّلاَةِ فَرَجَعَ وَقَدْ وَضَعَتْ ‏.‏ فَقَالَ مَالَهَا خَدَعَتْنِي خَدَعَهَا اللَّهُ ثُمَّ أَتَى النَّبِيَّ ـ صلى الله عليه وسلم ـ فَقَالَ ‏ "‏ سَبَقَ الْكِتَابُ أَجَلَهُ اخْطُبْهَا إِلَى نَفْسِهَا ‏"‏ ‏.‏\hadithno{2026}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Zubair bin 'Awwam that:he was married to Umm Kulthum bint 'Uqbah, and she said to him when she was pregnant. "I will accept one divorce." So he divorced her once. Then he went out for prayer, and when he came back she had given birth. He said: "What is wrong with her? She misled me may Allah mislead her!" Then he came to the Prophet (ﷺ), who said: "Her waiting period is over (and she is divorced); propose marriage a new to her}}
\hadithdefcmd{ibnmajah}{2027}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ أَبِي السَّنَابِلِ، قَالَ وَضَعَتْ سُبَيْعَةُ الأَسْلَمِيَّةُ بِنْتُ الْحَارِثِ حَمْلَهَا بَعْدَ وَفَاةِ زَوْجِهَا بِبِضْعٍ وَعِشْرِينَ لَيْلَةً فَلَمَّا تَعَلَّتْ مِنْ نِفَاسِهَا تَشَوَّفَتْ فَعِيبَ ذَلِكَ عَلَيْهَا وَذُكِرَ أَمْرُهَا لِلنَّبِيِّ ـ صلى الله عليه وسلم ـ فَقَالَ ‏ "‏ إِنْ تَفْعَلْ فَقَدْ مَضَى أَجَلُهَا ‏"‏ ‏.‏\hadithno{2027}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Sanabil said:"Subai'ah Aslamiyyah bint Harith gave birth twenty-odd days after her husband died. When her postnatal bleeding ended, she adorned herself, and was criticized for doing that. Her case was mentioned to the Prophet (ﷺ) and he said: 'If she does that, then her waiting period is over}}
\hadithdefcmd{ibnmajah}{2028}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ دَاوُدَ بْنِ أَبِي هِنْدٍ، عَنِ الشَّعْبِيِّ، عَنْ مَسْرُوقٍ، وَعَمْرِو بْنِ عُتْبَةَ، أَنَّهُمَا كَتَبَا إِلَى سُبَيْعَةَ بِنْتِ الْحَارِثِ يَسْأَلاَنِهَا عَنْ أَمْرِهَا، فَكَتَبَتْ إِلَيْهِمَا إِنَّهَا وَضَعَتْ بَعْدَ وَفَاةِ زَوْجِهَا بِخَمْسَةٍ وَعِشْرِينَ فَتَهَيَّأَتْ تَطْلُبُ الْخَيْرَ فَمَرَّ بِهَا أَبُو السَّنَابِلِ بْنُ بَعْكَكٍ فَقَالَ قَدْ أَسْرَعْتِ اعْتَدِّي آخِرَ الأَجَلَيْنِ أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا ‏.‏ فَأَتَيْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ فَقُلْتُ يَا رَسُولَ اللَّهِ اسْتَغْفِرْ لِي ‏.‏ قَالَ ‏"‏ وَمِمَّ ذَاكَ ‏"‏ ‏.‏ فَأَخْبَرْتُهُ ‏.‏ فَقَالَ ‏"‏ إِنْ وَجَدْتِ زَوْجًا صَالِحًا فَتَزَوَّجِي ‏"‏ ‏.‏\hadithno{2028}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Masruq and 'Amr bin 'Utbah wrote to Subai'ah bint Harith, asking about her case.:She wrote to them saying that she gave birth twenty-five days after her husband died. Then she prepared herself, seeking to remarry. Abu Sanabil bin Ba'kak passed by her and said: "You are in a hurry; observe waiting period for the longer period, four months and ten days." "So I went to the Prophet (ﷺ) and said: 'O Messenger of Allah, (ﷺ) pray for forgiveness for me.' He said: 'Why is that.” I told him (what had happened). He said: 'If you find a righteous husband then marry him}}
\hadithdefcmd{ibnmajah}{2029}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، وَمُحَمَّدُ بْنُ بَشَّارٍ، قَالاَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ دَاوُدَ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنِ الْمِسْوَرِ بْنِ مَخْرَمَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ أَمَرَ سُبَيْعَةَ أَنْ تَنْكِحَ إِذَا تَعَلَّتْ مِنْ نِفَاسِهَا ‏.‏\hadithno{2029}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Miswar bin Makhramah that:the Prophet (ﷺ) told Subai'ah to get married, when her postnatal bleeding ended}}
\hadithdefcmd{ibnmajah}{2030}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ مُسْلِمٍ، عَنْ مَسْرُوقٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ وَاللَّهِ لَمَنْ شَاءَ لاَعَنَّاهُ لأُنْزِلَتْ سُورَةُ النِّسَاءِ الْقُصْرَى بَعْدَ أَرْبَعَةِ أَشْهُرٍ وَعَشْرًا ‏.‏\hadithno{2030}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that' Abdullah bin Mas'ud said:"By Allah, for those who would like to go through the process of praying for Allah's curse to be upon the one who is wrong, the shorter Surah concerning women[l] was revealed after (the Verses[2] which speak of the waiting period of) four months and ten (days)." [1] (65:40), [2] (2:)}}
\hadithdefcmd{ibnmajah}{2031}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، سُلَيْمَانُ بْنُ حَيَّانَ عَنْ سَعْدِ بْنِ إِسْحَاقَ بْنِ كَعْبِ بْنِ عُجْرَةَ، عَنْ زَيْنَبَ بِنْتِ كَعْبِ بْنِ عُجْرَةَ، وَكَانَتْ، تَحْتَ أَبِي سَعِيدٍ الْخُدْرِيِّ أَنَّ أُخْتَهُ الْفُرَيْعَةَ بِنْتَ مَالِكٍ، قَالَتْ خَرَجَ زَوْجِي فِي طَلَبِ أَعْلاَجٍ لَهُ فَأَدْرَكَهُمْ بِطَرَفِ الْقَدُومِ فَقَتَلُوهُ فَجَاءَ نَعْىُ زَوْجِي وَأَنَا فِي دَارٍ مِنْ دُورِ الأَنْصَارِ شَاسِعَةٍ عَنْ دَارِ أَهْلِي فَأَتَيْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّهُ جَاءَ نَعْىُ زَوْجِي وَأَنَا فِي دَارٍ شَاسِعَةٍ عَنْ دَارِ أَهْلِي وَدَارِ إِخْوَتِي وَلَمْ يَدَعْ مَالاً يُنْفِقُ عَلَىَّ وَلاَ مَالاً وَرِثْتُهُ ‏.‏ وَلاَ دَارًا يَمْلِكُهَا فَإِنْ رَأَيْتَ أَنْ تَأْذَنَ لِي فَأَلْحَقَ بِدَارِ أَهْلِي وَدَارِ إِخْوَتِي فَإِنَّهُ أَحَبُّ إِلَىَّ وَأَجْمَعُ لِي فِي بَعْضِ أَمْرِي ‏.‏ قَالَ ‏"‏ فَافْعَلِي إِنْ شِئْتِ ‏"‏ ‏.‏ قَالَتْ فَخَرَجْتُ قَرِيرَةً عَيْنِي لِمَا قَضَى اللَّهُ لِي عَلَى لِسَانِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ حَتَّى إِذَا كُنْتُ فِي الْمَسْجِدِ - أَوْ فِي بَعْضِ الْحُجْرَةِ - دَعَانِي فَقَالَ ‏"‏ كَيْفَ زَعَمْتِ ‏"‏ ‏.‏ قَالَتْ فَقَصَصْتُ عَلَيْهِ فَقَالَ ‏"‏ امْكُثِي فِي بَيْتِكِ الَّذِي جَاءَ فِيهِ نَعْىُ زَوْجِكِ حَتَّى يَبْلُغَ الْكِتَابُ أَجَلَهُ ‏"‏ ‏.‏ قَالَتْ فَاعْتَدَدْتُ فِيهِ أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا ‏.‏\hadithno{2031}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Zainab bint Ka'b bin 'Ujrah, who was married to Abu Sa'eed Al-Khudri,:that his sister Furai'ah bint Malik said: "My husband went out to pursue some slaves of his. He caught up with them at the edge of Qadumttl and they killed him. News of his death reached me when I was in one of the houses of the Ansar, far away from the house of my family and my brothers. I went to the Prophet (ﷺ) and said: 'O Messenger of Allah (ﷺ), there has come to me news of my husband's death and I am in a house far away from the house of my people and the house of my brothers. He did not leave any money that could be spent on me, or any inheritance, or any house I may take possession of. If you think that you could give me permission to join my family and my brothers, then that is what I prefer and is better for me in some ways.' He said: 'Do that if you wish.' Then I went out, feeling happy with the ruling of Allah given upon the lips of the Messenger of Allah (ﷺ), until, when I was in the mosque, or, in one of the apartments, he called me and said: 'What did you say?' I told him the story, and he said: 'Stay in the house in which the news of your husband's death came to you, until your waiting period is ever."' She said: "So I observed the waiting period there for four months and ten (days)}}
\hadithdefcmd{ibnmajah}{2032}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا ابْنُ أَبِي الزِّنَادِ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، قَالَ دَخَلْتُ عَلَى مَرْوَانَ فَقُلْتُ لَهُ امْرَأَةٌ مِنْ أَهْلِكَ طُلِّقَتْ فَمَرَرْتُ عَلَيْهَا وَهِيَ تَنْتَقِلُ فَقَالَتْ أَمَرَتْنَا فَاطِمَةُ بِنْتُ قَيْسٍ وَأَخْبَرَتْنَا أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ أَمَرَهَا أَنْ تَنْتَقِلَ ‏.‏ فَقَالَ مَرْوَانُ هِيَ أَمَرَتْهُمْ بِذَلِكَ ‏.‏ قَالَ عُرْوَةُ فَقُلْتُ أَمَا وَاللَّهِ لَقَدْ عَابَتْ ذَلِكَ عَائِشَةُ وَقَالَتْ إِنَّ فَاطِمَةَ كَانَتْ فِي مَسْكَنٍ وَحْشٍ فَخِيفَ عَلَيْهَا فَلِذَلِكَ أَرْخَصَ لَهَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏\hadithno{2032}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Hisham bin 'Urwah that his father said:"I entered upon Marwan and said to him: 'A women from your family has been divorced. I passed by her and she was moving. She said: 'Fatimah bint Qais told us to do that, and she told us that the Messenger of Allah (ﷺ) told her to move.' Marwan said: 'She told them to do that."' 'Urwah said: "l said: 'By Allah, 'Aishah did not like that, and said: 'Fatimah was living in a deserted house and it was feared for her (safety and well being), so the Messenger of Allah (ﷺ) granted a concession to her}}
\hadithdefcmd{ibnmajah}{2033}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ قَالَتْ فَاطِمَةُ بِنْتُ قَيْسٍ يَا رَسُولَ اللَّهِ إِنِّي أَخَافُ أَنْ يُقْتَحَمَ عَلَىَّ ‏.‏ فَأَمَرَهَا أَنْ تَتَحَوَّلَ ‏.‏\hadithno{2033}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Aishah said:“Fatimah bint Qais said: 'O Messenger of Allah, (ﷺ) I am afraid that someone may enter upon me by force.' So he told her to move}}
\hadithdefcmd{ibnmajah}{2034}{حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، حَدَّثَنَا رَوْحٌ، ح وَحَدَّثَنَا أَحْمَدُ بْنُ مَنْصُورٍ، حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، جَمِيعًا عَنِ ابْنِ جُرَيْجٍ، أَخْبَرَنِي أَبُو الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ طُلِّقَتْ خَالَتِي فَأَرَادَتْ أَنْ تَجُدَّ نَخْلَهَا فَزَجَرَهَا رَجُلٌ أَنْ تَخْرُجَ إِلَيْهِ فَأَتَتِ النَّبِيَّ ـ صلى الله عليه وسلم ـ فَقَالَ ‏ "‏ بَلَى فَجُدِّي نَخْلَكِ فَإِنَّكِ عَسَى أَنْ تَصَدَّقِي أَوْ تَفْعَلِي مَعْرُوفًا ‏"‏ ‏.‏\hadithno{2034}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir bin 'Abdullah said:"My maternal aunt was divorced, and she wanted to collect the harvest from her date-palm trees. A man rebuked her for going out to the trees. She went to the Prophet (ﷺ), who said: 'No, go and collect the harvest from your trees, for perhaps you will give some in charity or do a good deed with it}}
\hadithdefcmd{ibnmajah}{2035}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي بَكْرِ بْنِ أَبِي الْجَهْمِ بْنِ صُخَيْرٍ الْعَدَوِيِّ، قَالَ سَمِعْتُ فَاطِمَةَ بِنْتَ قَيْسٍ، تَقُولُ إِنَّ زَوْجَهَا طَلَّقَهَا ثَلاَثًا فَلَمْ يَجْعَلْ لَهَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ سُكْنَى وَلاَ نَفَقَةً ‏.‏\hadithno{2035}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Bakr bin Abu Jahm bin Sukhair Al-'Adawi said:"I heard Fatimah bint Qais say that her husband divorced her ttree times, and the Messenger of Allah (ﷺ) did not say that she was entitled to accommodation and maintenance}}
\hadithdefcmd{ibnmajah}{2036}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ مُغِيرَةَ، عَنِ الشَّعْبِيِّ، قَالَ قَالَتْ فَاطِمَةُ بِنْتُ قَيْسٍ طَلَّقَنِي زَوْجِي عَلَى عَهْدِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ثَلاَثًا فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ سُكْنَى لَكِ وَلاَ نَفَقَةَ ‏"‏ ‏.‏\hadithno{2036}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Sha'bi said:Fatimah bint Qais said: “My husband divorced me at the time of the Messenger of Allah (ﷺ) three times. The Messenger of Allah (ﷺ) said: 'You have no right to accommodation or to maintenance.'”}}
\hadithdefcmd{ibnmajah}{2037}{حَدَّثَنَا أَحْمَدُ بْنُ الْمِقْدَامِ أَبُو الأَشْعَثِ الْعِجْلِيُّ، حَدَّثَنَا عُبَيْدُ بْنُ الْقَاسِمِ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ عَمْرَةَ بِنْتَ الْجَوْنِ، تَعَوَّذَتْ مِنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ حِينَ أُدْخِلَتْ عَلَيْهِ فَقَالَ ‏ "‏ لَقَدْ عُذْتِ بِمُعَاذٍ ‏"‏ ‏.‏ فَطَلَّقَهَا وَأَمَرَ أُسَامَةَ أَوْ أَنَسًا فَمَتَّعَهَا بِثَلاَثَةِ أَثْوَابٍ رَازِقِيَّةٍ ‏.‏\hadithno{2037}\hadithgrade{Al-Albani: Munkar; Muhammad Fouad Abd al-Baqi: Munkar; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Aishah that:'Amrah bint Jawn sought refuge.with Allah from the Messenger of Allah (ﷺ) when she was brought to him (as a bride) He said: "You have sought refuge with Him in Whom refuge is sought." So he divorced her and told Usamah or Anas to give her, a gift of three garments of white flax}}
\hadithdefcmd{ibnmajah}{2038}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَمْرُو بْنُ أَبِي سَلَمَةَ أَبُو حَفْصٍ التَّنِّيسِيُّ، عَنْ زُهَيْرٍ، عَنِ ابْنِ جُرَيْجٍ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِذَا ادَّعَتِ الْمَرْأَةُ طَلاَقَ زَوْجِهَا فَجَاءَتْ عَلَى ذَلِكَ بِشَاهِدٍ عَدْلٍ اسْتُحْلِفَ زَوْجُهَا فَإِنْ حَلَفَ بَطَلَتْ شَهَادَةُ الشَّاهِدِ وَإِنْ نَكَلَ فَنُكُولُهُ بِمَنْزِلَةِ شَاهِدٍ آخَرَ وَجَازَ طَلاَقُهُ ‏"‏ ‏.‏\hadithno{2038}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Amr bin Shu'aib, from his father, from his grandfather, that:the Prophet (ﷺ) said: "If a woman claims that her husband has divorced her, and she brings a witness of good character (to testify) to that, her husband should be asked to swear an oath. If he swears, that will invalidate the testimony of the witness, but if he refuses then that will be equivalent to a second witness, and the divorce will take effect}}
\hadithdefcmd{ibnmajah}{2039}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ حَبِيبِ بْنِ أَرْدَكَ، حَدَّثَنَا عَطَاءُ بْنُ أَبِي رَبَاحٍ، عَنْ يُوسُفَ بْنِ مَاهَكَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ ثَلاَثٌ جِدُّهُنَّ جِدٌّ وَهَزْلُهُنَّ جِدٌّ النِّكَاحُ وَالطَّلاَقُ وَالرَّجْعَةُ ‏"‏ ‏.‏\hadithno{2039}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Hurairah that:the Messenger of Allah (ﷺ) said: "There are three matters in which seriousness is serious and joking is serious: marriage, divorce and taking back (one's wife)}}
\hadithdefcmd{ibnmajah}{2040}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، وَعَبْدَةُ بْنُ سُلَيْمَانَ، ح وَحَدَّثَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، جَمِيعًا عَنْ سَعِيدِ بْنِ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنْ زُرَارَةَ بْنِ أَوْفَى، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ اللَّهَ تَجَاوَزَ لأُمَّتِي عَمَّا حَدَّثَتْ بِهِ أَنْفُسَهَا مَا لَمْ تَعْمَلْ بِهِ أَوْ تَكَلَّمْ بِهِ ‏"‏ ‏.‏\hadithno{2040}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that:the Messenger of Allah (ﷺ) said: "Allah has forgiven my nation for what they think of to themselves, so long as they do not act upon it or speak of it}}
\hadithdefcmd{ibnmajah}{2041}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ خَالِدِ بْنِ خِدَاشٍ، وَمُحَمَّدُ بْنُ يَحْيَى، قَالاَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ حَمَّادٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، ‏.‏ أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏"‏ رُفِعَ الْقَلَمُ عَنْ ثَلاَثَةٍ عَنِ النَّائِمِ حَتَّى يَسْتَيْقِظَ وَعَنِ الصَّغِيرِ حَتَّى يَكْبَرَ وَعَنِ الْمَجْنُونِ حَتَّى يَعْقِلَ أَوْ يُفِيقَ ‏"‏ ‏.‏ قَالَ أَبُو بَكْرٍ فِي حَدِيثِهِ ‏"‏ وَعَنِ الْمُبْتَلَى حَتَّى يَبْرَأَ ‏"‏ ‏.‏\hadithno{2041}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Aishah that:the Messenger of Allah said. "The Pen has been lifted from three : from the sleeping person until he awakens, from the minor until he grows up, and from the insane person until he comes to his senses."In his narration, (one of the narrators Abu Bakr (Ibn Abu Shaibah) said: "And from the afflicted person, unit he recovers}}
\hadithdefcmd{ibnmajah}{2042}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا ابْنُ جُرَيْجٍ، أَنْبَأَنَا الْقَاسِمُ بْنُ يَزِيدَ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ يُرْفَعُ الْقَلَمُ عَنِ الصَّغِيرِ وَعَنِ الْمَجْنُونِ وَعَنِ النَّائِمِ ‏"‏ ‏.‏\hadithno{2042}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Ali bin Abu Talib that:the Messenger of Allah (ﷺ) said: "The Pen is lifted from the minor, the insane person and the sleeper}}
\hadithdefcmd{ibnmajah}{2043}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُحَمَّدِ بْنِ يُوسُفَ الْفِرْيَابِيُّ، حَدَّثَنَا أَيُّوبُ بْنُ سُوَيْدٍ، حَدَّثَنَا أَبُو بَكْرٍ الْهُذَلِيُّ، عَنْ شَهْرِ بْنِ حَوْشَبٍ، عَنْ أَبِي ذَرٍّ الْغِفَارِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ اللَّهَ تَجَاوَزَ عَنْ أُمَّتِي الْخَطَأَ وَالنِّسْيَانَ وَمَا اسْتُكْرِهُوا عَلَيْهِ ‏"‏ ‏.‏\hadithno{2043}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Dharr Al-Ghifari that the Messenger of Allah (ﷺ) said:Allah has forgiven for me my nation their mistakes and forgetfulness, and what they are forced to do}}
\hadithdefcmd{ibnmajah}{2044}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ مِسْعَرٍ، عَنْ قَتَادَةَ، عَنْ زُرَارَةَ بْنِ أَوْفَى، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ اللَّهَ تَجَاوَزَ لأُمَّتِي عَمَّا تُوَسْوِسُ بِهِ صُدُورُهَا ‏.‏ مَا لَمْ تَعْمَلْ بِهِ أَوْ تَتَكَلَّمْ بِهِ وَمَا اسْتُكْرِهُوا عَلَيْهِ ‏"‏ ‏.‏\hadithno{2044}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Shadh; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the:Messenger of Allah (ﷺ) said : "Allah has forgiven my nation for the evil suggestions of their hearts, so long as they do not act upon it or speak of it, and for what they are forced to do}}
\hadithdefcmd{ibnmajah}{2045}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُصَفَّى الْحِمْصِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا الأَوْزَاعِيُّ، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِنَّ اللَّهَ وَضَعَ عَنْ أُمَّتِي الْخَطَأَ وَالنِّسْيَانَ وَمَا اسْتُكْرِهُوا عَلَيْهِ ‏"‏ ‏.‏\hadithno{2045}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn 'Abbas that the Prophet (ﷺ) said :"Allah has forgiven my nation for mistakes and forgetfulness, and what they are forced to do}}
\hadithdefcmd{ibnmajah}{2046}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ ثَوْرٍ، عَنْ عُبَيْدِ بْنِ أَبِي صَالِحٍ، عَنْ صَفِيَّةَ بِنْتِ شَيْبَةَ، قَالَتْ حَدَّثَتْنِي عَائِشَةُ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ طَلاَقَ وَلاَ عَتَاقَ فِي إِغْلاَقٍ ‏"‏ ‏.‏\hadithno{2046}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Safiyyah bint Shaibah said:"Aishah told me that the Messenger of Allah (ﷺ) said: 'There is no divorce and no manumission at the time of coercion}}
\hadithdefcmd{ibnmajah}{2047}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا هُشَيْمٌ، أَنْبَأَنَا عَامِرٌ الأَحْوَلُ، ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ، جَمِيعًا عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، ‏.‏ أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ طَلاَقَ فِيمَا لاَ يَمْلِكُ ‏"‏ ‏.‏\hadithno{2047}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from "Amr bin Shu'aib, from his father, from his grandfather, that:the Messenger of Allah said : "There is no divorce regarding that which one does not possess}}
\hadithdefcmd{ibnmajah}{2048}{حَدَّثَنَا أَحْمَدُ بْنُ سَعِيدٍ الدَّارِمِيُّ، حَدَّثَنَا عَلِيُّ بْنُ الْحُسَيْنِ بْنِ وَاقِدٍ، حَدَّثَنَا هِشَامُ بْنُ سَعْدٍ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنِ الْمِسْوَرِ بْنِ مَخْرَمَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ طَلاَقَ قَبْلَ نِكَاحٍ وَلاَ عِتْقَ قَبْلَ مِلْكٍ ‏"‏ ‏.‏\hadithno{2048}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Miswar bin Makharamah that the Prophet (ﷺ) said:"There is no divorce before marriage, and no manumission before taking possession}}
\hadithdefcmd{ibnmajah}{2049}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَنْبَأَنَا مَعْمَرٌ، عَنْ جُوَيْبِرٍ، عَنِ الضَّحَّاكِ، عَنِ النَّزَّالِ بْنِ سَبْرَةَ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ طَلاَقَ قَبْلَ النِّكَاحِ ‏"‏ ‏.‏\hadithno{2049}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from ' Ali bin Abu Talib that the Prophet (ﷺ) said :"There is no divorce before marriage}}
\hadithdefcmd{ibnmajah}{2050}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا الأَوْزَاعِيُّ، قَالَ سَأَلْتُ الزُّهْرِيَّ أَىُّ أَزْوَاجِ النَّبِيِّ ـ صلى الله عليه وسلم ـ اسْتَعَاذَتْ مِنْهُ فَقَالَ أَخْبَرَنِي عُرْوَةُ عَنْ عَائِشَةَ أَنَّ ابْنَةَ الْجَوْنِ لَمَّا دَخَلَتْ عَلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَدَنَا مِنْهَا قَالَتْ أَعُوذُ بِاللَّهِ مِنْكَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ عُذْتِ بِعَظِيمٍ ‏.‏ الْحَقِي بِأَهْلِكِ ‏"‏ ‏.‏\hadithno{2050}\hadithgrade{Al-Albani: Munkar; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Awza'i said :"I asked Zuhri: 'Which of the wives of the Prophet (ﷺ) sought refuge with Allah from him? He said : "Urwah told me, (narrating) from 'Aishah, that when the daughter of Jawn entered upon the Messenger of Allah (ﷺ) and he came close to her, she said: "I seek refuge with Allah from you." the Messenger of Allah (ﷺ) said : "You have sought refuge in the Almighty" go to your family}}
\hadithdefcmd{ibnmajah}{2051}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ جَرِيرِ بْنِ حَازِمٍ، عَنِ الزُّبَيْرِ بْنِ سَعِيدٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَلِيِّ بْنِ يَزِيدَ بْنِ رُكَانَةَ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّهُ طَلَّقَ امْرَأَتَهُ الْبَتَّةَ فَأَتَى رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ فَسَأَلَهُ فَقَالَ ‏"‏ مَا أَرَدْتَ بِهَا ‏"‏ ‏.‏ قَالَ وَاحِدَةً ‏.‏ قَالَ ‏"‏ آللَّهِ مَا أَرَدْتَ بِهَا إِلاَّ وَاحِدَةً قَالَ آللَّهِ مَا أَرَدْتُ بِهَا إِلاَّ وَاحِدَةً ‏.‏ قَالَ فَرَدَّهَا عَلَيْهِ ‏.‏ قَالَ مُحَمَّدُ بْنُ مَاجَهْ سَمِعْتُ أَبَا الْحَسَنِ عَلِيَّ بْنَ مُحَمَّدٍ الطَّنَافِسِيَّ يَقُولُ مَا أَشْرَفَ هَذَا الْحَدِيثَ ‏.‏ قَالَ ابْنُ مَاجَهْ أَبُو عُبَيْدٍ تَرَكَهُ نَاحِيَةً وَأَحْمَدُ جَبُنَ عَنْهُ ‏.‏\hadithno{2051}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Abdullah bin 'Ali bin Yazid bin Rukanah, from his father, from his grandfather, that:he divorced his wife irrevocably, then he came to the Messenger of Allah (ﷺ) and asked him. He said: "What did you mean by that?" He said: "One (divorce)." He said: "By Allah did you only mean one (divorce) thereby?" He said: "By Allah, I meant one." Then he sent her back to him. (Da'if)Muhammad bin Majah said: I heard Abul-Hasan ' Ali bin Muhammad Tanafisi saying: "How noble is this Hadith." Ibn Majah said: 'Abu 'Ubaid left it (i.e., did not accept its narration) and Ahmad was fearful of it (i.e., of narrating it)}}
\hadithdefcmd{ibnmajah}{2052}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ مُسْلِمٍ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ خَيَّرَنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَاخْتَرْنَاهُ ‏.‏ فَلَمْ نَرَهُ شَيْئًا ‏.‏\hadithno{2052}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Aishah said:"The Messenger of Allah gave us the choice, and we chose him, and he did not consider it as something (i.e., an effective divorce)}}
\hadithdefcmd{ibnmajah}{2053}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَنْبَأَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ لَمَّا نَزَلَتْ ‏\{وَإِنْ كُنْتُنَّ تُرِدْنَ اللَّهَ وَرَسُولَهُ\}‏ دَخَلَ عَلَىَّ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَ ‏"‏ يَا عَائِشَةُ إِنِّي ذَاكِرٌ لَكِ أَمْرًا فَلاَ عَلَيْكِ أَنْ لاَ تَعْجَلِي فِيهِ حَتَّى تَسْتَأْمِرِي أَبَوَيْكِ قَالَتْ قَدْ عَلِمَ وَاللَّهِ أَنَّ أَبَوَىَّ لَمْ يَكُونَا لِيَأْمُرَانِي بِفِرَاقِهِ ‏.‏ قَالَتْ فَقَرَأَ عَلَىَّ ‏\{يَا أَيُّهَا النَّبِيُّ قُلْ لأَزْوَاجِكَ إِنْ كُنْتُنَّ تُرِدْنَ الْحَيَاةَ الدُّنْيَا وَزِينَتَهَا \}‏ ‏.‏ الآيَاتِ ‏.‏ فَقُلْتُ فِي هَذَا أَسْتَأْمِرُ أَبَوَىَّ قَدِ اخْتَرْتُ اللَّهَ وَرَسُولَهُ ‏.‏\hadithno{2053}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Aishah said:"When the following was revealed: 'But if you desire Allah and His Messenger, (ﷺ) the Messenger of Allah (ﷺ) entered upon me and said: 'O Aishah I want to say something to you, and you do not have to hasten (in making a decision) until you have consulted your parents."' She said: "He knew, by Allah, that my parents would never tell me to leave him." She said: "Then he recited to me: ' O Prophet (Muhammad)! Say to your wives: " If you desire the life of this world, and its glitter.'" I said: 'Do I need to consult my parents about this? I choose Allah and His Messenger}}
\hadithdefcmd{ibnmajah}{2054}{حَدَّثَنَا بَكْرُ بْنُ خَلَفٍ أَبُو بِشْرٍ، حَدَّثَنَا أَبُو عَاصِمٍ، عَنْ جَعْفَرِ بْنِ يَحْيَى بْنِ ثَوْبَانَ، عَنْ عَمِّهِ، عُمَارَةَ بْنِ ثَوْبَانَ عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ تَسْأَلُ الْمَرْأَةُ زَوْجَهَا الطَّلاَقَ فِي غَيْرِ كُنْهِهِ فَتَجِدَ رِيحَ الْجَنَّةِ ‏.‏ وَإِنَّ رِيحَهَا لَيُوجَدُ مِنْ مَسِيرَةِ أَرْبَعِينَ عَامًا ‏"‏ ‏.‏\hadithno{2054}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn 'Abbas that the Prophet (ﷺ) said:"No woman asks for divorce when it is not absolutely necessary, but she will never smell the fragrance of paradise, although its fragrance can be detected from a distance of forty years' travel}}
\hadithdefcmd{ibnmajah}{2055}{حَدَّثَنَا أَحْمَدُ بْنُ الأَزْهَرِ، حَدَّثَنَا مُحَمَّدُ بْنُ الْفَضْلِ، عَنْ حَمَّادِ بْنِ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي أَسْمَاءَ، عَنْ ثَوْبَانَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أَيُّمَا امْرَأَةٍ سَأَلَتْ زَوْجَهَا الطَّلاَقَ فِي غَيْرِ مَا بَأْسٍ فَحَرَامٌ عَلَيْهَا رَائِحَةُ الْجَنَّةِ ‏"‏ ‏.‏\hadithno{2055}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Thawban that the Messenger of Allah (ﷺ) said:'Any woman who asks her husband for a divorce when it is not absolutely necessary, the fragrance of Paradise will be forbidden to her}}
\hadithdefcmd{ibnmajah}{2056}{حَدَّثَنَا أَزْهَرُ بْنُ مَرْوَانَ، حَدَّثَنَا عَبْدُ الأَعْلَى بْنُ عَبْدِ الأَعْلَى، حَدَّثَنَا سَعِيدُ بْنُ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ جَمِيلَةَ بِنْتَ سَلُولَ، أَتَتِ النَّبِيَّ ـ صلى الله عليه وسلم ـ فَقَالَتْ وَاللَّهِ مَا أَعْتِبُ عَلَى ثَابِتٍ فِي دِينٍ وَلاَ خُلُقٍ ‏.‏ وَلَكِنِّي أَكْرَهُ الْكُفْرَ فِي الإِسْلاَمِ لاَ أُطِيقُهُ بُغْضًا ‏.‏ فَقَالَ لَهَا النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏ "‏ أَتَرُدِّينَ عَلَيْهِ حَدِيقَتَهُ ‏"‏ ‏.‏ قَالَتْ نَعَمْ ‏.‏ فَأَمَرَهُ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَنْ يَأْخُذَ مِنْهَا حَدِيقَتَهُ وَلاَ يَزْدَادَ ‏.‏\hadithno{2056}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn 'Abbas that:Jamilah bint Salul came to the Prophet (ﷺ) and said: "By Allah, I do not find any fault with Thabit regarding his religion nor his behavior, but I hate disbelief after becoming Muslim and I cannot stand him. "The Prophet (ﷺ) said to her: 'WiIl you give him back his garden?" She said: "Yes." So the Messenger of Allah (ﷺ) told him to take back his garden from her and no more than that}}
\hadithdefcmd{ibnmajah}{2057}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنْ حَجَّاجٍ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ كَانَتْ حَبِيبَةُ بِنْتُ سَهْلٍ تَحْتَ ثَابِتِ بْنِ قَيْسِ بْنِ شَمَّاسٍ وَكَانَ رَجُلاً دَمِيمًا ‏.‏ فَقَالَتْ يَا رَسُولَ اللَّهِ وَاللَّهِ لَوْلاَ مَخَافَةُ اللَّهِ إِذَا دَخَلَ عَلَىَّ لَبَصَقْتُ فِي وَجْهِهِ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أَتَرُدِّينَ عَلَيْهِ حَدِيقَتَهُ ‏"‏ ‏.‏ قَالَتْ نَعَمْ ‏.‏ قَالَ فَرَدَّتْ عَلَيْهِ حَدِيقَتَهُ ‏.‏ قَالَ فَفَرَّقَ بَيْنَهُمَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏\hadithno{2057}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Amr bin Shu'aib, from his father, that his grandfather said:"Habibah bint Sahl was married to Thabit bin Qais bin Shammas, who was an ugly man. She said: 'O Messenger of Allah, (ﷺ) by Allah, were it not for fear of Allah when he enters upon me I would spit in his face.' The Messenger of Allah (ﷺ) said: 'Will you give him back his garden?' She :said: 'Yes.' So she gave him back his garden and the Messenger of Allah (ﷺ) separated them}}
\hadithdefcmd{ibnmajah}{2058}{حَدَّثَنَا عَلِيُّ بْنُ سَلَمَةَ النَّيْسَابُورِيُّ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ، حَدَّثَنَا أَبِي، عَنِ ابْنِ إِسْحَاقَ، أَخْبَرَنِي عُبَادَةُ بْنُ الْوَلِيدِ بْنِ عُبَادَةَ بْنِ الصَّامِتِ، عَنِ الرُّبَيِّعِ بِنْتِ مُعَوِّذِ ابْنِ عَفْرَاءَ، قَالَ قُلْتُ لَهَا حَدِّثِينِي حَدِيثَكِ، ‏.‏ قَالَتِ اخْتَلَعْتُ مِنْ زَوْجِي ثُمَّ جِئْتُ عُثْمَانَ ‏.‏ فَسَأَلْتُ مَاذَا عَلَىَّ مِنَ الْعِدَّةِ فَقَالَ لاَ عِدَّةَ عَلَيْكِ إِلاَّ أَنْ يَكُونَ حَدِيثَ عَهْدٍ بِكِ فَتَمْكُثِينَ عِنْدَهُ حَتَّى تَحِيضِينَ حَيْضَةً ‏.‏ قَالَتْ وَإِنَّمَا تَبِعَ فِي ذَلِكَ قَضَاءَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فِي مَرْيَمَ الْمَغَالِيَّةِ ‏.‏ وَكَانَتْ تَحْتَ ثَابِتِ بْنِ قَيْسٍ فَاخْتَلَعَتْ مِنْهُ ‏.‏\hadithno{2058}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Ubadah bin Samit from Rubai' bint Mu'awwidh bin 'Afra'.:He said: "I said to her: 'Tell me your Hadith.' She said: 'I got Khul' from my husband, then I came to 'Uthman and asked him: "What waiting period do I have to observe?" He said: "You do not have to observe any waiting period, unless you had intercourse with him recently, in which case you should stay with him until you have menstruated." In that he was following the ruling of the Messenger of Allah (ﷺ) concerning Maryam Maghaliyyah, who was married to Thabit bin Qais and she got Khul' from him}}
\hadithdefcmd{ibnmajah}{2059}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ أَبِي الرِّجَالِ، عَنْ أَبِيهِ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، قَالَتْ أَقْسَمَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَنْ لاَ يَدْخُلَ عَلَى نِسَائِهِ شَهْرًا فَمَكَثَ تِسْعَةً وَعِشْرِينَ يَوْمًا حَتَّى إِذَا كَانَ مَسَاءَ ثَلاَثِينَ دَخَلَ عَلَىَّ فَقُلْتُ إِنَّكَ أَقْسَمْتَ أَنْ لاَ تَدْخُلَ عَلَيْنَا شَهْرًا ‏.‏ فَقَالَ ‏"‏ شَهْرٌ هَكَذَا ‏"‏ ‏.‏ يُرْسِلُ أَصَابِعَهُ فِيهَا ثَلاَثَ مَرَّاتٍ ‏"‏ وَشَهْرٌ هَكَذَا ‏"‏ ‏.‏ وَأَرْسَلَ أَصَابِعَهُ كُلَّهَا وَأَمْسَكَ إِصْبَعًا وَاحِدًا فِي الثَّالِثَةِ ‏.‏\hadithno{2059}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah (ﷺ) swore that he would not enter upon his wives for a month, and he stayed for twenty-nine days until, on the eve of the thirtieth, he entered upon me. I said: 'You swore not to enter upon us for a month.' He said: 'The month may be like this,' and he held up his (ten) fingers three times; 'or the month may be like this,' and he held up his fingers three times, keeping one finger down on the third time}}
\hadithdefcmd{ibnmajah}{2060}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا يَحْيَى بْنُ زَكَرِيَّا بْنِ أَبِي زَائِدَةَ، عَنْ حَارِثَةَ بْنِ مُحَمَّدٍ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ إِنَّمَا آلَى لأَنَّ زَيْنَبَ رَدَّتْ عَلَيْهِ هَدِيَّتَهُ ‏.‏ فَقَالَتْ عَائِشَةُ لَقَدْ أَقْمَأَتْكَ ‏.‏ فَغَضِبَ ـ صلى الله عليه وسلم ـ فَآلَى مِنْهُنَّ ‏.‏\hadithno{2060}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Aishah that:the Messenger of Allah (ﷺ) swore to keep away from his wives, because Zainab had sent back her gift and 'Aishah said: "She has disgraced you." He became angry and swore to keep away from them}}
\hadithdefcmd{ibnmajah}{2061}{حَدَّثَنَا أَحْمَدُ بْنُ يُوسُفَ السُّلَمِيُّ، حَدَّثَنَا أَبُو عَاصِمٍ، عَنِ ابْنِ جُرَيْجٍ، عَنْ يَحْيَى بْنِ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ صَيْفِيٍّ، عَنْ عِكْرِمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أُمِّ سَلَمَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ آلَى مِنْ بَعْضِ نِسَائِهِ شَهْرًا فَلَمَّا كَانَ تِسْعَةً وَعِشْرِينَ رَاحَ أَوْ غَدَا ‏.‏ فَقِيلَ يَا رَسُولَ اللَّهِ إِنَّمَا مَضَى تِسْعٌ وَعِشْرُونَ ‏.‏ فَقَالَ ‏ "‏ الشَّهْرُ تِسْعٌ وَعِشْرُونَ ‏"‏ ‏.‏\hadithno{2061}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Umm Salamah that:the Messenger of Allah (ﷺ) swore to keep away from some of his wives for a month. On the twenty-ninth day, in the evening or the morning, it was said: "O Messenger of Allah, only twenty-nine days have passed." He said: "The month is twenty-nine days}}
\hadithdefcmd{ibnmajah}{2062}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ إِسْحَاقَ، عَنْ مُحَمَّدِ بْنِ عَمْرِو بْنِ عَطَاءٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ سَلَمَةَ بْنِ صَخْرٍ الْبَيَاضِيِّ، قَالَ كُنْتُ امْرَأً أَسْتَكْثِرُ مِنَ النِّسَاءِ لاَ أُرَى رَجُلاً كَانَ يُصِيبُ مِنْ ذَلِكَ مَا أُصِيبُ فَلَمَّا دَخَلَ رَمَضَانُ ظَاهَرْتُ مِنِ امْرَأَتِي حَتَّى يَنْسَلِخَ رَمَضَانُ فَبَيْنَمَا هِيَ تُحَدِّثُنِي ذَاتَ لَيْلَةٍ انْكَشَفَ لِي مِنْهَا شَىْءٌ فَوَثَبْتُ عَلَيْهَا فَوَاقَعْتُهَا فَلَمَّا أَصْبَحْتُ غَدَوْتُ عَلَى قَوْمِي فَأَخْبَرْتُهُمْ خَبَرِي وَقُلْتُ لَهُمْ سَلُوا لِي رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏ فَقَالُوا مَا كُنَّا لِنَفْعَلَ إِذًا يُنْزِلَ اللَّهُ فِينَا كِتَابًا أَوْ يَكُونَ فِينَا مِنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَوْلٌ فَيَبْقَى عَلَيْنَا عَارُهُ وَلَكِنْ سَوْفَ نُسَلِّمُكَ لِجَرِيرَتِكَ اذْهَبْ أَنْتَ فَاذْكُرْ شَأْنَكَ لِرَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏ قَالَ فَخَرَجْتُ حَتَّى جِئْتُهُ فَأَخْبَرْتُهُ الْخَبَرَ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ أَنْتَ بِذَاكَ ‏"‏ ‏.‏ فَقُلْتُ أَنَا بِذَاكَ وَهَا أَنَا يَا رَسُولَ اللَّهِ صَابِرٌ لِحُكْمِ اللَّهِ عَلَىَّ ‏.‏ قَالَ ‏"‏ فَأَعْتِقْ رَقَبَةً ‏"‏ ‏.‏ قَالَ قُلْتُ وَالَّذِي بَعَثَكَ بِالْحَقِّ مَا أَصْبَحْتُ أَمْلِكُ إِلاَّ رَقَبَتِي هَذِهِ ‏.‏ قَالَ ‏"‏ فَصُمْ شَهْرَيْنِ مُتَتَابِعَيْنِ ‏"‏ ‏.‏ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ وَهَلْ دَخَلَ عَلَىَّ مَا دَخَلَ مِنَ الْبَلاَءِ إِلاَّ بِالصَّوْمِ قَالَ ‏"‏ فَتَصَدَّقْ وَأَطْعِمْ سِتِّينَ مِسْكِينًا ‏"‏ ‏.‏ قَالَ قُلْتُ وَالَّذِي بَعَثَكَ بِالْحَقِّ لَقَدْ بِتْنَا لَيْلَتَنَا هَذِهِ مَا لَنَا عَشَاءٌ ‏.‏ قَالَ ‏"‏ فَاذْهَبْ إِلَى صَاحِبِ صَدَقَةِ بَنِي زُرَيْقٍ فَقُلْ لَهُ فَلْيَدْفَعْهَا إِلَيْكَ وَأَطْعِمْ سِتِّينَ مِسْكِينًا وَانْتَفِعْ بِبَقِيَّتِهَا ‏"‏ ‏.‏\hadithno{2062}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Salamah bin Sakhr Al-Bayadi said:"I was a man who had a lot of desire for women, and I do not think there was any man who had as great a share of that as me. When Ramadan began, I declared Zihar upon my wife (to last) until Ramadan ended. While she was talking to me one night, part of her body became uncovered. I jumped on her and had intercourse with her. The next morning I went to my people and told them, and said to them: 'Ask the Messenger of Allah (ﷺ) for me.' They said: 'We will not do that, lest Allah reveal Quran concerning us or the Messenger of Allah (ﷺ) says, something about us, and it will be a lasting source of disgrace for us. Rather we will leave you to deal with it yourself. Go yourself and tell the Messenger of Allah (ﷺ) about your problem.' So I went out and when I came to him, I told him what happened. The Messenger of Allah (ﷺ) said: 'Did you really do that?' I said: 'I really did that, and here I am, O Messenger of Allah. (ﷺ) I will bear Allah’s ruling on me with patience.' He said: 'Free a slave.' I said: 'By the One Who sent you with the truth, I do not own anything but myself.' He said: 'Fast for two consecutive months.' I said: 'O Messenger of Allah, the thing that happened to me was only because of fasting.' He said: 'Then give charity, or feed sixty poor persons.' I said: 'By the One Who sent you with the truttu we spent last night with no dinner.' He said: 'Then go to the collector of charity of Banu Zuraiq, and tell him to give you something, then feed sixty poor persons, and benefit from the rest}}
\hadithdefcmd{ibnmajah}{2063}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي عُبَيْدَةَ، حَدَّثَنَا أَبِي، عَنِ الأَعْمَشِ، عَنْ تَمِيمِ بْنِ سَلَمَةَ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، قَالَ قَالَتْ عَائِشَةُ تَبَارَكَ الَّذِي وَسِعَ سَمْعُهُ كُلَّ شَىْءٍ ‏.‏ إِنِّي لأَسْمَعُ كَلاَمَ خَوْلَةَ بِنْتِ ثَعْلَبَةَ وَيَخْفَى عَلَىَّ بَعْضُهُ وَهِيَ تَشْتَكِي زَوْجَهَا إِلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ وَهِيَ تَقُولُ يَا رَسُولَ اللَّهِ أَكَلَ شَبَابِي وَنَثَرْتُ لَهُ بَطْنِي حَتَّى إِذَا كَبِرَتْ سِنِّي وَانْقَطَعَ وَلَدِي ظَاهَرَ مِنِّي اللَّهُمَّ إِنِّي أَشْكُو إِلَيْكَ ‏.‏ فَمَا بَرِحَتْ حَتَّى نَزَلَ جِبْرَائِيلُ بِهَؤُلاَءِ الآيَاتِ ‏\{‏قَدْ سَمِعَ اللَّهُ قَوْلَ الَّتِي تُجَادِلُكَ فِي زَوْجِهَا وَتَشْتَكِي إِلَى اللَّهِ‏\}‏‏.‏\hadithno{2063}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Urwah bin Zubair, that 'Aishah said:"Blessed is the One Whose hearing encompasses all things. I heard some of the words of Khawlah bint Tha'labah, but some of her words were not clear to me, when she complained to the Messenger of Allah (ﷺ) about her husband, and said: 'O Messenger of Allah, (ﷺ) he has consumed my youth and I split my belly for him (i.e., bore him many children), but when I grew old and could no longer bear children he declared Zihar upon me; O Allah, I complain to You.' She continued to complain until Jibra'il brought down these Verses: 'Indeed Allah has heard the statement of she who pleads with you (O Muhammad) concerning her husband, and complains to Allah" (58:)}}
\hadithdefcmd{ibnmajah}{2064}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ مُحَمَّدِ بْنِ عَمْرِو بْنِ عَطَاءٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ سَلَمَةَ بْنِ صَخْرٍ الْبَيَاضِيِّ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ فِي الْمُظَاهِرِ يُوَاقِعُ قَبْلَ أَنْ يُكَفِّرَ قَالَ ‏ "‏ كَفَّارَةٌ وَاحِدَةٌ ‏"‏ ‏.‏\hadithno{2064}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Salamah bin Sakhr Al-Bayedi that:the Prophet (ﷺ) said concerning a man who declared Zihar upon his wife having intercourse with her before compensation: "Let him offer one expiation}}
\hadithdefcmd{ibnmajah}{2065}{حَدَّثَنَا الْعَبَّاسُ بْنُ يَزِيدَ، قَالَ حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا مَعْمَرٌ، عَنِ الْحَكَمِ بْنِ أَبَانَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَجُلاً، ظَاهَرَ مِنِ امْرَأَتِهِ فَغَشِيَهَا قَبْلَ أَنْ يُكَفِّرَ فَأَتَى النَّبِيَّ ـ صلى الله عليه وسلم ـ فَذَكَرَ ذَلِكَ لَهُ فَقَالَ ‏ "‏ مَا حَمَلَكَ عَلَى ذَلِكَ ‏"‏ ‏.‏ فَقَالَ يَا رَسُولَ اللَّهِ رَأَيْتُ بَيَاضَ حِجْلَيْهَا فِي الْقَمَرِ فَلَمْ أَمْلِكْ نَفْسِي أَنْ وَقَعْتُ عَلَيْهَا ‏.‏ فَضَحِكَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَأَمَرَهُ أَلاَّ يَقْرَبَهَا حَتَّى يُكَفِّرَ ‏.‏\hadithno{2065}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Ibn 'Abbas that:a man declared Zihar upon his wife, then he had intercourse with her before offering expiation. He came to the Prophet (ﷺ) and told him about that. He said: "What made you do that?" He said: "I saw her ankles in the moonlight, and I could not control myself, and I had intercourse with her." The Messenger of Allah (ﷺ) smiled and told him not to go near her until he had offered expiation}}
\hadithdefcmd{ibnmajah}{2066}{حَدَّثَنَا أَبُو مَرْوَانَ، مُحَمَّدُ بْنُ عُثْمَانَ الْعُثْمَانِيُّ حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَهْلِ بْنِ سَعْدٍ السَّاعِدِيِّ، قَالَ جَاءَ عُوَيْمِرٌ إِلَى عَاصِمِ بْنِ عَدِيٍّ فَقَالَ سَلْ لِي رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ أَرَأَيْتَ رَجُلاً وَجَدَ مَعَ امْرَأَتِهِ رَجُلاً فَقَتَلَهُ أَيُقْتَلُ بِهِ أَمْ كَيْفَ يَصْنَعُ فَسَأَلَ عَاصِمٌ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ عَنْ ذَلِكَ فَعَابَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ الْمَسَائِلَ ‏.‏ ثُمَّ لَقِيَهُ عُوَيْمِرٌ فَسَأَلَهُ فَقَالَ مَا صَنَعْتَ فَقَالَ صَنَعْتُ أَنَّكَ لَمْ تَأْتِنِي بِخَيْرٍ سَأَلْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ فَعَابَ الْمَسَائِلَ فَقَالَ عُوَيْمِرٌ وَاللَّهِ لآتِيَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ وَلأَسْأَلَنَّهُ ‏.‏ فَأَتَى رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ فَوَجَدَهُ قَدْ أُنْزِلَ عَلَيْهِ فِيهِمَا فَلاَعَنَ بَيْنَهُمَا فَقَالَ عُوَيْمِرٌ وَاللَّهِ لَئِنِ انْطَلَقْتُ بِهَا يَا رَسُولَ اللَّهِ لَقَدْ كَذَبْتُ عَلَيْهَا ‏.‏ قَالَ فَفَارَقَهَا قَبْلَ أَنْ يَأْمُرَهُ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَصَارَتْ سُنَّةً فِي الْمُتَلاَعِنَيْنِ ثُمَّ قَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏ "‏ انْظُرُوهَا فَإِنْ جَاءَتْ بِهِ أَسْحَمَ أَدْعَجَ الْعَيْنَيْنِ عَظِيمَ الأَلْيَتَيْنِ فَلاَ أُرَاهُ إِلاَّ قَدْ صَدَقَ عَلَيْهَا وَإِنْ جَاءَتْ بِهِ أُحَيْمِرَ كَأَنَّهُ وَحَرَةٌ فَلاَ أُرَاهُ إِلاَّ كَاذِبًا ‏"‏ ‏.‏ قَالَ فَجَاءَتْ بِهِ عَلَى النَّعْتِ الْمَكْرُوهِ ‏.‏\hadithno{2066}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Sahl bin Sa'd As-Sa'idi said:"Uwaimir came to 'Asim bin 'Adi and said: 'Ask the Messenger of Ailah (ﷺ) for me: "Do you think that if a man finds another man with his wife and kills him, he should be killed in retaliation, or what should he do?" 'Asim asked the Messenger of Allah (ﷺ) about that, and the Messenger of Allah (ﷺ) disapproved of the question. Then 'Uwaimir met him ('Asim) and asked him about that, saying: 'What did you do?’ He said: I did that and you have not brought me any good. I asked the Messenger of Allah (ﷺ) and he disapproved of this question.’ Uwaimir said: 'By Allah, I will go to the Messenger of Allah (ﷺ) myself and ask him.' So he went to the Messenger of Allah (ﷺ) and found that Qur'an had been revealed concerning them, and the Prophet (ﷺ) told them to go through the procedure of Li'an. 'Uwaimir said: 'O Messenger of Allah, (ﷺ) by Allah if I take her back, I would have been telling lies about her.' So he left her before the Messenger of Allah (ﷺ) told him to do so, and that became the Sunnah for two who engage in the procedure of Li'an. Then the Prophet (ﷺ) said: 'Wait and see. If she gives birth to a child who is black in color with widely-spaced dark eyes and large buttocks, then I think that he was telling the truth about her, but if she gives birth to a child with a red complexion like a Wahrah,[1] then I think that he was lying.' Then she gave birth to a child with features resembling those of the man concerning whom she was accused}}
\hadithdefcmd{ibnmajah}{2067}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، قَالَ أَنْبَأَنَا هِشَامُ بْنُ حَسَّانَ، حَدَّثَنَا عِكْرِمَةُ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ هِلاَلَ بْنَ أُمَيَّةَ، قَذَفَ امْرَأَتَهُ عِنْدَ النَّبِيِّ ـ صلى الله عليه وسلم ـ بِشَرِيكِ بْنِ سَحْمَاءَ فَقَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏"‏ الْبَيِّنَةُ أَوْ حَدٌّ فِي ظَهْرِكَ ‏"‏ ‏.‏ فَقَالَ هِلاَلُ بْنُ أُمَيَّةَ وَالَّذِي بَعَثَكَ بِالْحَقِّ إِنِّي لَصَادِقٌ وَلَيُنْزِلَنَّ اللَّهُ فِي أَمْرِي مَا يُبَرِّئُ ظَهْرِي ‏.‏ قَالَ فَنَزَلَتْ ‏\{‏وَالَّذِينَ يَرْمُونَ أَزْوَاجَهُمْ وَلَمْ يَكُنْ لَهُمْ شُهَدَاءُ إِلاَّ أَنْفُسُهُمْ‏\}‏ ‏.‏ حَتَّى بَلَغَ ‏\{‏وَالْخَامِسَةَ أَنَّ غَضَبَ اللَّهِ عَلَيْهَا إِنْ كَانَ مِنَ الصَّادِقِينَ‏\}‏ ‏.‏ فَانْصَرَفَ النَّبِيُّ ـ صلى الله عليه وسلم ـ فَأَرْسَلَ إِلَيْهِمَا فَجَاءَا فَقَامَ هِلاَلُ بْنُ أُمَيَّةَ فَشَهِدَ وَالنَّبِيُّ ـ صلى الله عليه وسلم ـ يَقُولُ ‏"‏ إِنَّ اللَّهَ يَعْلَمُ أَنَّ أَحَدَكُمَا كَاذِبٌ فَهَلْ مِنْ تَائِبٍ ‏"‏ ‏.‏ ثُمَّ قَامَتْ فَشَهِدَتْ فَلَمَّا كَانَ عِنْدَ الْخَامِسَةِ ‏\{‏أَنَّ غَضَبَ اللَّهِ عَلَيْهَا إِنْ كَانَ مِنَ الصَّادِقِينَ‏\}‏ ‏.‏ قَالُوا لَهَا إِنَّهَا الْمُوجِبَةُ ‏.‏ قَالَ ابْنُ عَبَّاسٍ فَتَلَكَّأَتْ وَنَكَصَتْ حَتَّى ظَنَنَّا أَنَّهَا سَتَرْجِعُ فَقَالَتْ وَاللَّهِ لاَ أَفْضَحُ قَوْمِي سَائِرَ الْيَوْمِ ‏.‏ فَقَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏"‏ انْظُرُوهَا فَإِنْ جَاءَتْ بِهِ أَكْحَلَ الْعَيْنَيْنِ سَابِغَ الأَلْيَتَيْنِ خَدَلَّجَ السَّاقَيْنِ فَهُوَ لِشَرِيكِ بْنِ سَحْمَاءَ ‏"‏ ‏.‏ فَجَاءَتْ بِهِ كَذَلِكَ فَقَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏"‏ لَوْلاَ مَا مَضَى مِنْ كِتَابِ اللَّهِ لَكَانَ لِي وَلَهَا شَأْنٌ ‏"‏ ‏.‏\hadithno{2067}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Ibn 'Abbas that:Hilal bin Umayyah accused his wife in the presence of the Prophet (ﷺ) of (committing adultery) with Sharik bin Sahma'. The Prophet said: "Bring proof or you will feel the Hadd (punishment) on your back." Hilal bin Umayyah said: "By the One Who sent you with the truth, I am telling the truth, and Allah will send down revelation concerning my situation which will spare my back." Then the following was revealed: "And for those who accuse their wives, but have no witnesses except themselves, let the testimony of one of them be four testimonies (i.e., testifies four times) by Allah that he is one of those who speak the truth. And the fifth (testimony should be) the invoking of the curse of Allah on him if he be of those who tell a lie (against her). But it shall avert the punishment (of stoning to death) from her, it she bears witness four times by Allah, that he (her husband) is telling a lie. And the fifth (testimony) should be that the wrath of Allah be upon her if he (her husband) speaks the truth." The Prophet (ﷺ), turned and sent for them, and they came. Hilal bin Umayyah stood up and bore witness, and the Prophet (ﷺ) said: "Allah knows that one of you is lying. Will either of you repent?" Then she stood up and affirmed her innocence. On the fifth time, meaning that the wrath of Allah be upon her if he (her husband) speaks the truth, they said to her: "It will invoke the wrath of Allah." Ibn 'Abbas said: "She hesitated and backed up, until we thought that she was going to recant. Then she said: 'By Allah, I cannot dishonor my people for ever.' Then the Prophet (ﷺ) said: 'Wait and see. If she gives birth to a child with black eyes, fleshy buttocks and big calves, then he is the son of Sharik bin Sahma'.' And she gave birth to such a child. Then the Prophet (ﷺ) said: 'Had it not the matter been settled by the Book of Allah, I would have punished her severely}}
\hadithdefcmd{ibnmajah}{2068}{حَدَّثَنَا أَبُو بَكْرِ بْنُ خَلاَّدٍ الْبَاهِلِيُّ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ بْنِ حَبِيبٍ، قَالاَ حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ كُنَّا فِي الْمَسْجِدِ لَيْلَةَ الْجُمُعَةِ ‏.‏ فَقَالَ رَجُلٌ لَوْ أَنَّ رَجُلاً وَجَدَ مَعَ امْرَأَتِهِ رَجُلاً فَقَتَلَهُ قَتَلْتُمُوهُ وَإِنْ تَكَلَّمَ جَلَدْتُمُوهُ وَاللَّهِ لأَذْكُرَنَّ ذَلِكَ لِلنَّبِيِّ ـ صلى الله عليه وسلم ـ ‏.‏ فَذَكَرَهُ لِلنَّبِيِّ ـ صلى الله عليه وسلم ـ فَأَنْزَلَ اللَّهُ آيَاتِ اللِّعَانِ ‏.‏ ثُمَّ جَاءَ الرَّجُلُ بَعْدَ ذَلِكَ يَقْذِفُ امْرَأَتَهُ فَلاَعَنَ النَّبِيُّ ـ صلى الله عليه وسلم ـ بَيْنَهُمَا وَقَالَ ‏ "‏ عَسَى أَنْ تَجِيءَ بِهِ أَسْوَدَ ‏"‏ ‏.‏ فَجَاءَتْ بِهِ أَسْوَدَ جَعْدًا ‏.‏\hadithno{2068}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Abdullah said:"We were in the mosque one Friday night when a man said: 'If a man finds a man with his wife and kills him, will you kill him, and if he speaks,will you flog him. By Allah I will mention that to the Prophet (ﷺ). So he mentioned that to the Prophet (ﷺ), and Allah revealed the Verses of Li'an. Then after that the man came and accused his wife, so the Prophet (ﷺ) told them to go through the procedure of Li'an and he said: 'Perhaps she will give birth to a black child.’ Then she gave birth to a black child with curly hair}}
\hadithdefcmd{ibnmajah}{2069}{حَدَّثَنَا أَحْمَدُ بْنُ سِنَانٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَجُلاً، لاَعَنَ امْرَأَتَهُ وَانْتَفَى مِنْ وَلَدِهَا فَفَرَّقَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ بَيْنَهُمَا وَأَلْحَقَ الْوَلَدَ بِالْمَرْأَةِ ‏.‏\hadithno{2069}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Umar that:a man invoked curses on his wife, and refused to accept her child. The Messenger of Allah (ﷺ) separated them, and left the child with the woman}}
\hadithdefcmd{ibnmajah}{2070}{حَدَّثَنَا عَلِيُّ بْنُ سَلَمَةَ النَّيْسَابُورِيُّ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ، حَدَّثَنَا أَبِي، عَنِ ابْنِ إِسْحَاقَ، قَالَ ذَكَرَ طَلْحَةُ بْنُ نَافِعٍ عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ تَزَوَّجَ رَجُلٌ مِنَ الأَنْصَارِ امْرَأَةً مِنْ بَلْعِجْلاَنَ فَدَخَلَ بِهَا فَبَاتَ عِنْدَهَا فَلَمَّا أَصْبَحَ قَالَ مَا وَجَدْتُهَا عَذْرَاءَ فَرُفِعَ شَأْنُهَا إِلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ فَدَعَا الْجَارِيَةَ فَسَأَلَهَا فَقَالَتْ بَلَى قَدْ كُنْتُ عَذْرَاءَ ‏.‏ فَأَمَرَ بِهِمَا فَتَلاَعَنَا وَأَعْطَاهَا الْمَهْرَ ‏.‏\hadithno{2070}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn 'Abbas said:"A man from among the Ansar manried a wornan from Bal'ijlan. He entered upon her and spent the night with her, then in the morning he said: 'I did not find her to be a virgin.' Her case was taken to the Prophet (ﷺ), and he called the girl and asked her. She said: 'No, I was a virgin.' So he told thern to go through the procedure of Li'an, and gave her the bridal-money.” (D a'if)}}
\hadithdefcmd{ibnmajah}{2071}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا حَيْوَةُ بْنُ شُرَيْحٍ الْحَضْرَمِيُّ، عَنْ ضَمْرَةَ بْنِ رَبِيعَةَ، عَنِ ابْنِ عَطَاءٍ، عَنْ أَبِيهِ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ أَرْبَعٌ مِنَ النِّسَاءِ لاَ مُلاَعَنَةَ بَيْنَهُنَّ النَّصْرَانِيَّةُ تَحْتَ الْمُسْلِمِ وَالْيَهُودِيَّةُ تَحْتَ الْمُسْلِمِ وَالْحُرَّةُ تَحْتَ الْمَمْلُوكِ وَالْمَمْلُوكَةُ تَحْتَ الْحُرِّ ‏"‏ ‏.‏\hadithno{2071}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was nanated from 'Amr bin Shu'aib, from his father, from his grandfather, that:the Prophet (ﷺ) said: "There are four kinds of women for whom there is no Li'an: a Christian woman married to a Muslim, a Jewish woman married to a Muslim, a free woman married to a slave, and a slave woman married to a free man}}
\hadithdefcmd{ibnmajah}{2072}{حَدَّثَنَا الْحَسَنُ بْنُ قَزَعَةَ، حَدَّثَنَا مَسْلَمَةُ بْنُ عَلْقَمَةَ، حَدَّثَنَا دَاوُدُ بْنُ أَبِي هِنْدٍ، عَنْ عَامِرٍ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ آلَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ مِنْ نِسَائِهِ وَحَرَّمَ فَجَعَلَ الْحَرَامَ حَلاَلاً ‏.‏ وَجَعَلَ فِي الْيَمِينِ كَفَّارَةً ‏.‏\hadithno{2072}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah swore to keep away from his wives and declared them as unlawful for him, so he made something permissible forbidden, and he offered expiation for having sworn to do so}}
\hadithdefcmd{ibnmajah}{2073}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، حَدَّثَنَا هِشَامٌ الدَّسْتَوَائِيُّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ يَعْلَى بْنِ حَكِيمٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، قَالَ قَالَ ابْنُ عَبَّاسٍ فِي الْحَرَامِ يَمِينٌ ‏.‏ وَكَانَ ابْنُ عَبَّاسٍ يَقُولُ لَقَدْ كَانَ لَكُمْ فِي رَسُولِ اللَّهِ أُسْوَةٌ حَسَنَةٌ ‏.‏\hadithno{2073}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Sa'eed bin Jubair that Ibn 'Abbas said:"For the one who makes unlawful is the swearing." (Sahih)And Ibn 'Abbas used to say: "You had the best example in the Messenger of Allah." (33:)}}
\hadithdefcmd{ibnmajah}{2074}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ بْنِ يَزِيدَ، عَنْ عَائِشَةَ، أَنَّهَا أَعْتَقَتْ بَرِيرَةَ فَخَيَّرَهَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَكَانَ لَهَا زَوْجٌ حُرٌّ ‏.‏\hadithno{2074}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Aishah that:she freed Barirah and the Messenger of Allah (ﷺ) gave her the choice, and she (Barirah) had a free husband}}
\hadithdefcmd{ibnmajah}{2075}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ خَلاَّدٍ الْبَاهِلِيُّ، قَالاَ حَدَّثَنَا عَبْدُ الْوَهَّابِ الثَّقَفِيُّ، حَدَّثَنَا خَالِدٌ الْحَذَّاءُ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ زَوْجُ بَرِيرَةَ عَبْدًا يُقَالُ لَهُ مُغِيثٌ كَأَنِّي أَنْظُرُ إِلَيْهِ يَطُوفُ خَلْفَهَا وَيَبْكِي وَدُمُوعُهُ تَسِيلُ عَلَى خَدِّهِ فَقَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ لِلْعَبَّاسِ ‏"‏ يَا عَبَّاسُ أَلاَ تَعْجَبُ مِنْ حُبِّ مُغِيثٍ بَرِيرَةَ وَمِنْ بُغْضِ بَرِيرَةَ مُغِيثًا ‏"‏ ‏.‏ فَقَالَ لَهَا النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏"‏ لَوْ رَاجَعْتِيهِ فَإِنَّهُ أَبُو وَلَدِكِ ‏"‏ ‏.‏ قَالَتْ يَا رَسُولَ اللَّهِ تَأْمُرُنِي قَالَ ‏"‏ إِنَّمَا أَشْفَعُ ‏"‏ ‏.‏ قَالَتْ لاَ حَاجَةَ لِي فِيهِ ‏.‏\hadithno{2075}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Ibn 'Abbas said:"The husband of Barirah was a slave called Mughith. It is as if I can see him now, walking behind her and weeping, with tears running down his cheeks. The Prophet (ﷺ) said to 'Abbas: 'O Abbas, are you not amazed by the love of Mughith for Barirah, and the hatred of Barirah for Mughith?' And the Prophet said to her: Why don’t you take him back, for he is the father of your child?' She said: 'O Messenger of Allah, are you commanding me (to do so)?' He said: 'No, rather I am interceding.' She said: 'I have no need of him}}
\hadithdefcmd{ibnmajah}{2076}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ، قَالَتْ مَضَى فِي بَرِيرَةَ ثَلاَثُ سُنَنٍ خُيِّرَتْ حِينَ أُعْتِقَتْ وَكَانَ زَوْجُهَا مَمْلُوكًا وَكَانُوا يَتَصَدَّقُونَ عَلَيْهَا فَتُهْدِي إِلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ فَيَقُولُ ‏"‏ هُوَ عَلَيْهَا صَدَقَةٌ وَهُوَ لَنَا هَدِيَّةٌ ‏"‏ ‏.‏ وَقَالَ ‏"‏ الْوَلاَءُ لِمَنْ أَعْتَقَ ‏"‏ ‏.‏\hadithno{2076}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Aishah said:'Three Sunan were established because of Barirah: She was given the choice (of whether to remain married) when she was freed, and her husband was a slave; they used to give her charity and she used to give it as a gift to the Prophet (ﷺ), and he would say: 'It is charity for her and a gift for us,' and he said, the 'Wala' is for the one who set the slave free}}
\hadithdefcmd{ibnmajah}{2077}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ أُمِرَتْ بَرِيرَةُ أَنْ تَعْتَدَّ، بِثَلاَثِ حِيَضٍ ‏.‏\hadithno{2077}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Aishah said:"Barirah was told to observe the waiting period for three menstrual cycles}}
\hadithdefcmd{ibnmajah}{2078}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ تَوْبَةَ، حَدَّثَنَا عَبَّادُ بْنُ الْعَوَّامِ، عَنْ يَحْيَى بْنِ أَبِي إِسْحَاقَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أُذَيْنَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ خَيَّرَ بَرِيرَةَ ‏.‏\hadithno{2078}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Hurairah that:the Messenger of Allah (ﷺ) gave Barirah the choice}}
\hadithdefcmd{ibnmajah}{2079}{حَدَّثَنَا مُحَمَّدُ بْنُ طَرِيفٍ، وَإِبْرَاهِيمُ بْنُ سَعِيدٍ الْجَوْهَرِيُّ، قَالاَ حَدَّثَنَا عُمَرُ بْنُ شَبِيبٍ الْمُسْلِيُّ، عَنْ عَبْدِ اللَّهِ بْنِ عِيسَى، عَنْ عَطِيَّةَ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ طَلاَقُ الأَمَةِ اثْنَتَانِ وَعِدَّتُهَا حَيْضَتَانِ ‏"‏ ‏.‏\hadithno{2079}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn 'Urnar that the Messenger of Allah (ﷺ), said:"The divorce of a slave woman is twice, and her waiting period is two menstrual cycles}}
\hadithdefcmd{ibnmajah}{2080}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو عَاصِمٍ، حَدَّثَنَا ابْنُ جُرَيْجٍ، عَنْ مُظَاهِرِ بْنِ أَسْلَمَ، عَنِ الْقَاسِمِ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏"‏ طَلاَقُ الأَمَةِ تَطْلِيقَتَانِ وَقُرْؤُهَا حَيْضَتَانِ ‏"‏ ‏.‏ قَالَ أَبُو عَاصِمٍ فَذَكَرْتُهُ لِمُظَاهِرٍ فَقُلْتُ حَدِّثْنِي كَمَا حَدَّثْتَ ابْنَ جُرَيْجٍ ‏.‏ فَأَخْبَرَنِي عَنِ الْقَاسِمِ عَنْ عَائِشَةَ عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏"‏ طَلاَقُ الأَمَةِ تَطْلِيقَتَانِ وَقُرْؤُهَا حَيْضَتَانِ ‏"‏ ‏.‏\hadithno{2080}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Aishah that the Prophet (ﷺ) said:"The divorce of a slave woman is twice, and her (waiting) period is two menstrual cycles." Abu 'Asim said: "I mentioned this to Muzahir and said: 'Tell me what you told Ibn Juraij.' So he told me, narrating from Qasim from 'Aishah, that the Prophet (ﷺ) said: 'The divorce of a slave woman is twice, and her (waiting) period is two menstrual cycles}}
\hadithdefcmd{ibnmajah}{2081}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا يَحْيَى بْنُ عَبْدِ اللَّهِ بْنِ بُكَيْرٍ، حَدَّثَنَا ابْنُ لَهِيعَةَ، عَنْ مُوسَى بْنِ أَيُّوبَ الْغَافِقِيِّ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ أَتَى النَّبِيَّ ـ صلى الله عليه وسلم ـ رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ سَيِّدِي زَوَّجَنِي أَمَتَهُ وَهُوَ يُرِيدُ أَنْ يُفَرِّقَ بَيْنِي وَبَيْنَهَا ‏.‏ قَالَ فَصَعِدَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ الْمِنْبَرَ فَقَالَ ‏ "‏ يَا أَيُّهَا النَّاسُ مَا بَالُ أَحَدِكُمْ يُزَوِّجَ عَبْدَهُ أَمَتَهُ ثُمَّ يُرِيدُ أَنْ يُفَرِّقَ بَيْنَهُمَا إِنَّمَا الطَّلاَقُ لِمَنْ أَخَذَ بِالسَّاقِ ‏"‏ ‏.‏\hadithno{2081}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn 'Abbas said:"A man came to the Prophet (ﷺ) and said: 'O Messenger of Allah, my master married me to his slave woman, and now he wants to separate me and her.' The Messenger of Allah (ﷺ) ascended the pulpit and said: 'O people, what is the matter with one of you who marries his slave to his slave woman, then wants to separate them? Divorce belongs to the one who takes hold of the calf (i.e., her husband).’ “}}
\hadithdefcmd{ibnmajah}{2082}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ زَنْجَوَيْهِ أَبُو بَكْرٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ عُمَرَ بْنِ مُعَتِّبٍ، عَنْ أَبِي الْحَسَنِ، مَوْلَى بَنِي نَوْفَلٍ قَالَ سُئِلَ ابْنُ عَبَّاسٍ عَنْ عَبْدٍ طَلَّقَ، امْرَأَتَهُ تَطْلِيقَتَيْنِ ثُمَّ أُعْتِقَا أَيَتَزَوَّجُهَا قَالَ نَعَمْ ‏.‏ فَقِيلَ لَهُ عَمَّنْ قَالَ قَضَى بِذَلِكَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏ قَالَ عَبْدُ الرَّزَّاقِ قَالَ عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ لَقَدْ تَحَمَّلَ أَبُو الْحَسَنِ هَذَا صَخْرَةً عَظِيمَةً عَلَى عُنُقِهِ ‏.‏\hadithno{2082}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{lt was narrated that Abul Hasan, the freed slave of Banu Nawfal, said:"Ibn 'Abbas was asked about a slave who divorces his wife twice, then (they are freed). Can he marry her? He said: 'Yes.' It was said to him: 'On what basis?' He said: 'The Messenger of Allah (ﷺ) passed such a judgement .' " (D a' if)}}
\hadithdefcmd{ibnmajah}{2083}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ سَعِيدِ بْنِ أَبِي عَرُوبَةَ، عَنْ مَطَرٍ الْوَرَّاقِ، عَنْ رَجَاءِ بْنِ حَيْوَةَ، عَنْ قَبِيصَةَ بْنِ ذُؤَيْبٍ، عَنْ عَمْرِو بْنِ الْعَاصِ، قَالَ لاَ تُفْسِدُوا عَلَيْنَا سُنَّةَ نَبِيِّنَا مُحَمَّدٍ ـ صلى الله عليه وسلم ـ عِدَّةُ أُمِّ الْوَلَدِ أَرْبَعَةُ أَشْهُرٍ وَعَشْرًا ‏.‏\hadithno{2083}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Amr bin 'As said:"Do not corrupt the Sunnah of our Prophet Muhammad (ﷺ). The waiting period of an Umm Walad is four months and ten (days)}}
\hadithdefcmd{ibnmajah}{2084}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ حُمَيْدِ بْنِ نَافِعٍ، ‏.‏ أَنَّهُ سَمِعَ زَيْنَبَ ابْنَةَ أُمِّ سَلَمَةَ، تُحَدِّثُ أَنَّهَا سَمِعَتْ أُمَّ سَلَمَةَ، وَأُمَّ حَبِيبَةَ تَذْكُرَانِ أَنَّ امْرَأَةً أَتَتِ النَّبِيَّ ـ صلى الله عليه وسلم ـ فَقَالَتْ إِنَّ ابْنَةً لَهَا تُوُفِّيَ عَنْهَا زَوْجُهَا فَاشْتَكَتْ عَيْنُهَا فَهِيَ تُرِيدُ أَنْ تَكْحَلَهَا ‏.‏ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ قَدْ كَانَتْ إِحْدَاكُنَّ تَرْمِي بِالْبَعْرَةِ عِنْدَ رَأْسِ الْحَوْلِ وَإِنَّمَا هِيَ أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا ‏"‏ ‏.‏\hadithno{2084}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Humaid bin Nafi' that:he heard Zainab the daughter of Umm Salamah narrating that she heard Umm Salamah and Umm Habibah mention that a woman came to the Prophet (ﷺ) and said that her daughter's husband had died, and she was suffering from an eye disease, and she wanted to apply kohl to her eyes (as a remedy). The Messenger of Allah (ﷺ) said: "One of you would throw a she-camel's dropping when a year had passed (since the death of her husband. Rather it is four months and ten (days)}}
\hadithdefcmd{ibnmajah}{2085}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ يَحِلُّ لاِمْرَأَةٍ أَنْ تُحِدَّ عَلَى مَيِّتٍ فَوْقَ ثَلاَثٍ إِلاَّ عَلَى زَوْجٍ ‏"‏ ‏.‏\hadithno{2085}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Aishah that:the Prophet (ﷺ) said: "It is not permissible for a woman to mourn for any deceased person for more than three days, except for her husband}}
\hadithdefcmd{ibnmajah}{2086}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ نَافِعٍ، عَنْ صَفِيَّةَ بِنْتِ أَبِي عُبَيْدٍ، عَنْ حَفْصَةَ، زَوْجِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَتْ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ يَحِلُّ لاِمْرَأَةٍ تُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ أَنْ تُحِدَّ عَلَى مَيِّتٍ فَوْقَ ثَلاَثٍ إِلاَّ عَلَى زَوْجٍ ‏"‏ ‏.‏\hadithno{2086}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Hafsah the wife of the Prophet (ﷺ) that:the Messenger of Allah (ﷺ), said: "It is not permissible for a woman who believes in Allah and the Last Day to mourn for any deceased person for more than three days, except for her husband}}
\hadithdefcmd{ibnmajah}{2087}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ هِشَامِ بْنِ حَسَّانَ، عَنْ حَفْصَةَ، عَنْ أُمِّ عَطِيَّةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ تُحِدُّ عَلَى مَيِّتٍ فَوْقَ ثَلاَثٍ إِلاَّ الْمَرْأَةُ تُحِدُّ عَلَى زَوْجِهَا أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا وَلاَ تَلْبَسُ ثَوْبًا مَصْبُوغًا إِلاَّ ثَوْبَ عَصْبٍ وَلاَ تَكْتَحِلُ وَلاَ تَطَيَّبُ إِلاَّ عِنْدَ أَدْنَى طُهْرِهَا بِنُبْذَةٍ مِنْ قُسْطٍ وَأَظْفَارٍ ‏"‏ ‏.‏\hadithno{2087}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Umm 'Atiyyah that the Messenger of Allah (ﷺ) said:'No deceased person should be mourned for more than three days, except a woman should mourn for her husband for four months and ten days, and she should not wear dyed clothes, except for a garment of 'Asb, and she should not wear kohl or perfume, except at the beginning of her purity, when she may apply a little Qust and Azfar.’”}}
\hadithdefcmd{ibnmajah}{2088}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ، وَعُثْمَانُ بْنُ عُمَرَ، قَالاَ حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، عَنْ خَالِهِ الْحَارِثِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ حَمْزَةَ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ كَانَتْ تَحْتِي امْرَأَةٌ وَكُنْتُ أُحِبُّهَا وَكَانَ أَبِي يُبْغِضُهَا فَذَكَرَ ذَلِكَ عُمَرُ لِلنَّبِيِّ ـ صلى الله عليه وسلم ـ فَأَمَرَنِي أَنْ أُطَلِّقَهَا فَطَلَّقْتُهَا ‏.‏\hadithno{2088}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that 'Abdullah bin 'Umar said:"I had a wife whom I loved, but my father hated her. 'Umar mentioned that to the Prophet (ﷺ) and he ordered me to divorce her, so I divorced her}}
\hadithdefcmd{ibnmajah}{2089}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ، أَنَّ رَجُلاً، أَمَرَهُ أَبُوهُ أَوْ أُمُّهُ - شَكَّ شُعْبَةُ - أَنْ يُطَلِّقَ، امْرَأَتَهُ فَجَعَلَ عَلَيْهِ مِائَةَ مُحَرَّرٍ ‏.‏ فَأَتَى أَبَا الدَّرْدَاءِ فَإِذَا هُوَ يُصَلِّي الضُّحَى وَيُطِيلُهَا وَصَلَّى مَا بَيْنَ الظُّهْرِ وَالْعَصْرِ فَسَأَلَهُ فَقَالَ أَبُو الدَّرْدَاءِ أَوْفِ بِنَذْرِكَ وَبَرَّ وَالِدَيْكَ ‏.‏ وَقَالَ أَبُو الدَّرْدَاءِ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ الْوَالِدُ أَوْسَطُ أَبْوَابِ الْجَنَّةِ فَحَافِظْ عَلَى وَالِدَيْكَ أَوِ اتْرُكْ ‏"‏ ‏.‏\hadithno{2089}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Abdur-Rahman that:a man's father or mother - Shu'bah (one of the namators) was not sure - ordered him to divorce his wife, and he made a vow that he would free one hundred slaves if he did that. He came to Abu Darda' while he was praying the Duha, and he was making his prayer lengthy, and he prayed between Zuhr and 'Asr. Then he asked him and Abu Darda' said: "Fulfill your vow and honor your parents." Abu Ad-Darda' said: "I heard the Messenger of Allah (ﷺ) say: '(Honoring) one's father may lead one to enter through the best of the gates of Paradise; so take care of your parents, (it is so, whether you take care of them) or not}}
\hadithdefcmd{ibnmajah}{2435}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا رِشْدِينُ بْنُ سَعْدٍ، وَعَبْدُ الرَّحْمَنِ الْمُحَارِبِيُّ، وَأَبُو أُسَامَةَ وَجَعْفَرُ بْنُ عَوْنٍ عَنِ ابْنِ أَنْعُمٍ، قَالَ أَبُو كُرَيْبٍ وَحَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنِ ابْنِ أَنْعُمٍ، عَنِ عِمْرَانَ بْنِ عَبْدٍ الْمَعَافِرِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ الدَّيْنَ يُقْضَى مِنْ صَاحِبِهِ يَوْمَ الْقِيَامَةِ إِذَا مَاتَ إِلاَّ مَنْ يَدَيَّنُ فِي ثَلاَثِ خِلاَلٍ الرَّجُلُ تَضْعُفُ قُوَّتُهُ فِي سَبِيلِ اللَّهِ فَيَسْتَدِينُ يَتَقَوَّى بِهِ لِعَدُوِّ اللَّهِ وَعَدُوِّهِ وَرَجُلٌ يَمُوتُ عِنْدَهُ مُسْلِمٌ لاَ يَجِدُ مَا يُكَفِّنُهُ وَيُوَارِيهِ إِلاَّ بِدَيْنٍ وَرَجُلٌ خَافَ اللَّهَ عَلَى نَفْسِهِ الْعُزْبَةَ فَيَنْكِحُ خَشْيَةً عَلَى دِينِهِ فَإِنَّ اللَّهَ يَقْضِي عَنْ هَؤُلاَءِ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{2435}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Abdullah bin 'Amr that the Messenger of Allah (ﷺ) said:“A debt will be settled on the Day of Resurrection if the one who owes it dies, apart from three: A man who lost his strength fighting in the cause of Allah (SWT), so he borrows in order to become strong again to fighting in the cause of Allah (SWT), so he borrows in order to become strong again to fight the enemy of Allah (SWT) and his enemy. A man who sees a Muslims die and he cannot find anything with which to shroud him except by taking a loan. A man who sees a Muslim die and he cannot find anything with which to shroud him except, by taking a loan. A man who fears Allah (SWT) if he stays single, so he gets married for fear of (losing) his religious commitment. Allah will pay off the debt for these people on the Day of Resurrection.”}}
\hadithdefcmd{ibnmajah}{2464}{حَدَّثَنَا أَبُو بَكْرِ بْنُ خَلاَّدٍ الْبَاهِلِيُّ، وَمُحَمَّدُ بْنُ إِسْمَاعِيلَ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ طَاوُسٍ، قَالَ قَالَ ابْنُ عَبَّاسٍ إِنَّمَا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لأَنْ يَمْنَحَ أَحَدُكُمْ أَخَاهُ الأَرْضَ خَيْرٌ لَهُ مِنْ أَنْ يَأْخُذَ لَهَا خَرَاجًا مَعْلُومًا ‏"‏ ‏.‏\hadithno{2464}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Tawus that Ibn`Abbas told that the Messenger of Allah (ﷺ) merely said:“For one of you to give (land) to his brother is better for him than if he were to take a set amount in rent for it.”}}
\hadithdefcmd{ibnmajah}{2476}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ أَبِي الْمِنْهَالِ، سَمِعْتُ إِيَاسَ بْنَ عَبْدٍ الْمُزَنِيَّ، وَرَأَى، أُنَاسًا يَبِيعُونَ الْمَاءَ فَقَالَ لاَ تَبِيعُوا الْمَاءَ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى أَنْ يُبَاعَ الْمَاءُ ‏.‏\hadithno{2476}\hadithgrade{Al-Albani: Sahih Hadith; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Minhal said:“I heard Iyas bin 'Abd Muzani say - when he saw people selling water: 'Do not sell water, for I heard the Messenger of Allah (ﷺ) forbidding selling of water.' ”}}
\hadithdefcmd{ibnmajah}{2477}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، وَإِبْرَاهِيمُ بْنُ سَعِيدٍ الْجَوْهَرِيُّ، قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا ابْنُ جُرَيْجٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ بَيْعِ فَضْلِ الْمَاءِ ‏.‏\hadithno{2477}\hadithgrade{Al-Albani: Sahih Hadith; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir said:“The Messenger of Allah (ﷺ) forbade selling surplus water.”}}
